# wtforglib

[![Build Status](https://github.com/wtfo-guru/wtforglib/workflows/Wtforglib/badge.svg?branch=main&event=push)](https://github.com/wtfo-guru/wtforglib/actions?query=workflow%3AWtforglib)
[![codecov](https://codecov.io/gh/wtfo-guru/wtforglib/branch/main/graph/badge.svg)](https://codecov.io/gh/wtfo-guru/wtforglib)
[![Python Version](https://img.shields.io/pypi/pyversions/wtforglib.svg)](https://pypi.org/project/wtforglib/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

A set of utility functions I use in my various python projects.

## Features

- Fully typed with annotations and checked with mypy, [PEP561 compatible](https://www.python.org/dev/peps/pep-0561/)
- Add yours!


## Installation

```bash
pip install wtforglib
```

## Documentation

- [Stable](https://wtforglib.readthedocs.io/en/stable)

- [Latest](https://wtforglib.readthedocs.io/en/latest)

## License

[MIT](https://github.com/wtfo-guru/wtforglib/blob/main/LICENSE)

## Credits

This project was generated with [`wemake-python-package`](https://github.com/wemake-services/wemake-python-package). Current template version is: [5fe13ee2646d5cf38736bacfa8f9dbbfac092efb](https://github.com/wemake-services/wemake-python-package/tree/5fe13ee2646d5cf38736bacfa8f9dbbfac092efb). See what is [updated](https://github.com/wemake-services/wemake-python-package/compare/5fe13ee2646d5cf38736bacfa8f9dbbfac092efb...main) since then.
